import React from "react";
import { RoomMember } from "matrix-js-sdk/src/models/room-member";
import { MatrixCall } from "matrix-js-sdk/src/webrtc/call";
import { DirectoryMember, Member, ThreepidMember } from "../../../utils/direct-messages";
import { KIND_CALL_TRANSFER, KIND_DM, KIND_INVITE } from "./InviteDialogTypes";
interface Result {
    userId: string;
    user: RoomMember | DirectoryMember | ThreepidMember;
    lastActive?: number;
}
declare enum TabId {
    UserDirectory = "users",
    DialPad = "dialpad"
}
interface BaseProps {
    onFinished: (success: boolean) => void;
    initialText?: string;
}
interface InviteDMProps extends BaseProps {
    kind?: typeof KIND_DM;
}
interface InviteRoomProps extends BaseProps {
    kind: typeof KIND_INVITE;
    roomId: string;
}
interface InviteCallProps extends BaseProps {
    kind: typeof KIND_CALL_TRANSFER;
    call: MatrixCall;
}
type Props = InviteDMProps | InviteRoomProps | InviteCallProps;
interface IInviteDialogState {
    targets: Member[];
    filterText: string;
    recents: Result[];
    numRecentsShown: number;
    suggestions: Result[];
    numSuggestionsShown: number;
    serverResultsMixin: Result[];
    threepidResultsMixin: Result[];
    canUseIdentityServer: boolean;
    tryingIdentityServer: boolean;
    consultFirst: boolean;
    dialPadValue: string;
    currentTabId: TabId;
    busy: boolean;
    errorText: string;
}
export default class InviteDialog extends React.PureComponent<Props, IInviteDialogState> {
    static defaultProps: {
        kind: string;
        initialText: string;
    };
    private debounceTimer;
    private editorRef;
    private numberEntryFieldRef;
    private unmounted;
    constructor(props: any);
    componentDidMount(): void;
    componentWillUnmount(): void;
    private onConsultFirstChange;
    static buildRecents(excludedTargetIds: Set<string>): Result[];
    private buildSuggestions;
    private shouldAbortAfterInviteError;
    private convertFilter;
    private startDm;
    private inviteUsers;
    private transferCall;
    private onKeyDown;
    private onCancel;
    private updateSuggestions;
    private updateFilter;
    private showMoreRecents;
    private showMoreSuggestions;
    private toggleMember;
    private removeMember;
    private onPaste;
    private onClickInputArea;
    private onUseDefaultIdentityServerClick;
    private onManageSettingsClick;
    private renderSection;
    private renderEditor;
    private renderIdentityServerWarning;
    private onDialFormSubmit;
    private onDialChange;
    private onDigitPress;
    private onDeletePress;
    private onTabChange;
    private onLinkClick;
    private get screenName();
    render(): JSX.Element;
}
export {};
